==> kpeople-5.15.0.zip: kpeople-5.15.0/src/widgets/abstractfieldwidgetfactory.h <==
/*
    Copyright (C) 2013  David Edmundson <davidedmundson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef ABSTRACTFIELDWIDGETFACTORY_H
#define ABSTRACTFIELDWIDGETFACTORY_H

#include <QWidget>
#include <QIcon>

#include <kpeople/kpeople_export.h>

namespace KPeople
{
class AbstractFieldWidgetFactoryPrivate;
class PersonData;

class KPEOPLE_EXPORT AbstractFieldWidgetFactory : public QObject
{
    Q_OBJECT
public:
    explicit AbstractFieldWidgetFactory(QObject *parent = 0);
    virtual ~AbstractFieldWidgetFactory();

    virtual QString label() const = 0;
    virtual int sortWeight() const
    {
        return 100;
    }

    virtual QWidget *createDetailsWidget(const KPeople::PersonData &person, QWidget *parent) const = 0;
};
}

#endif // ABSTRACTFIELDWIDGETFACTORY_H

==> kpeople-5.64.0.zip: kpeople-5.64.0/src/widgets/abstractfieldwidgetfactory.h <==
/*
    Copyright (C) 2013  David Edmundson <davidedmundson@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef ABSTRACTFIELDWIDGETFACTORY_H
#define ABSTRACTFIELDWIDGETFACTORY_H

#include <QWidget>

#include <kpeople/widgets/kpeoplewidgets_export.h>

namespace KPeople
{
class AbstractFieldWidgetFactoryPrivate;
class PersonData;

class KPEOPLEWIDGETS_EXPORT AbstractFieldWidgetFactory : public QObject
{
    Q_OBJECT
public:
    explicit AbstractFieldWidgetFactory(QObject *parent = nullptr);
    virtual ~AbstractFieldWidgetFactory();

    virtual QString label() const = 0;
    virtual int sortWeight() const
    {
        return 100;
    }

    virtual QWidget *createDetailsWidget(const KPeople::PersonData &person, QWidget *parent) const = 0;
};
}

#endif // ABSTRACTFIELDWIDGETFACTORY_H
